@@ -6,8 +6,8 @@ use Math::Geometry::Construction;
 use Math::VectorReal;
 use SVG::Rasterize;
 
-my $construction = Math::Geometry::Construction->new(width  => 800,
-						     height => 300);
+my $construction = Math::Geometry::Construction->new
+    (background => 'white');
 
 sub line {
     my $p1 = $construction->add_point('x' => 500, 'y' => 100, hidden => 1);
@@ -15,9 +15,8 @@ sub line {
 				      style    => {stroke => 'none',
 						   fill   => 'blue',
 						   'fill-opacity' => 0.5});
-    my $l1 = $construction->add_line(extend => 50);
-    $l1->add_support($p1);
-    $l1->add_support($p2);
+    my $l1 = $construction->add_line(extend  => 50,
+				     support => [$p1, $p2]);
 }
 
 sub intersection {
@@ -33,20 +32,17 @@ sub intersection {
 
     my $l1 = $construction->add_line(extend         => 10,
 				     label          => 'g',
-				     label_offset_y => 13);
-    $l1->add_support($p1);
-    $l1->add_support($p2);
-    my $l2 = $construction->add_line;
-    $l2->add_support($p3);
-    $l2->add_support($p4);
+				     label_offset_y => 13,
+				     support        => [$p1, $p2]);
+    my $l2 = $construction->add_line(support => [$p3, $p4]);
 
     my $i1 = $construction->add_derivate('IntersectionLineLine',
 					 input => [$l1, $l2]);
     my $p5 = $i1->create_derived_point
-	(point_selector => ['indexed_point', [0]],
-	 label          => 'S',
-	 label_offset_x => 5,
-	 label_offset_y => -5);
+	(position_selector => ['indexed_position', [0]],
+	 label             => 'S',
+	 label_offset_x    => 5,
+	 label_offset_y    => -5);
 }
 
 sub circle {
@@ -58,22 +54,21 @@ sub circle {
     my $p03 = $construction->add_point('x' => 200, 'y' => 50, hidden => 1);
     my $p04 = $construction->add_point('x' => 200, 'y' => 60, hidden => 1);
 
-    my $l1 = $construction->add_line(hidden => 1);
-    $l1->add_support($p03);
-    $l1->add_support($p04);
+    my $l1 = $construction->add_line(hidden  => 1,
+				     support => [$p03, $p04]);
 
     my $i1 = $construction->add_derivate('IntersectionCircleLine',
 					 input => [$l1, $c1]);
     my $p05 = $i1->create_derived_point
-	(point_selector => ['indexed_point', [0]],
-	 label          => 'T',
-	 label_offset_x => 5,
-	 label_offset_y => -5);
+	(position_selector => ['indexed_position', [0]],
+	 label             => 'T',
+	 label_offset_x    => 5,
+	 label_offset_y    => -5);
     my $p06 = $i1->create_derived_point
-	(point_selector => ['indexed_point', [1]],
-	 label          => 'U',
-	 label_offset_x => 5,
-	 label_offset_y => -5);
+	(position_selector => ['indexed_position', [1]],
+	 label             => 'U',
+	 label_offset_x    => 5,
+	 label_offset_y    => -5);
 
     my $p07 = $construction->add_point('x' => 350, 'y' => 200);
     my $p08 = $construction->add_point('x' => 350, 'y' => 240, hidden => 1);
@@ -87,16 +82,22 @@ sub circle {
     my $i2 = $construction->add_derivate('IntersectionCircleCircle',
 					 input => [$c2, $c3]);
     my $p11 = $i2->create_derived_point
-	(point_selector => ['indexed_point', [0]]);
+	(position_selector => ['indexed_position', [0]]);
     my $p12 = $i2->create_derived_point
-	(point_selector => ['indexed_point', [1]]);
+	(position_selector => ['indexed_position', [1]]);
 }
 
 line;
 intersection;
 circle;
-    
-my $svg = $construction->as_svg(width => 800, height => 300);
+
+# width/height are on purpose not proportional to those of the
+# construction; this is to show how you can hand over SVG
+# parameters
+my $svg = $construction->as_svg(width => 600, height => 450,
+				viewBox             => "0 0 800 300",
+				preserveAspectRatio => "xMinYMid",
+				'font-family'       => 'Times');
     
 print $svg->xmlify, "\n";
     
